# Timeline
- !2019/12/08 [+]class3:url_od_tfidf,url_phish_lexical,xss_word2vec
- !2019/12/09 [+]argparse parse params
- !2019/12/09 [+]二刷笔记.xlsx Summarizing 2 articles 
- !2019/12/10 [+]二刷笔记.xlsx Summarizing 3 articles
- !2019/12/10 [!]learning Keras Tokenizer/Word2vec
- !2019/12/11 [+]class1:url_od_word_index using Keras Tokenizer
- !2019/12/13 [+]readme.md 
- !2019/12/18 [+]class4:malware feature extraction by integrating malware dynamic behavior dection by cnn@ApplePig@云影实验室@360
- !2019/12/19 [+]demand and design
- !2020/03/17 [+]重构TFIDF模块
- !2020/03/17 [+]从NLP角度重构整体结构。数据层、特征化层、算法层分层coding，先不考虑具体安全场景，从NLP角度写通用代码。

# Get
- 文本向量化
	- keras的Tokenizer类支持二进制值、词频、索引、TFIDF权重
	- word2vec支持词嵌入向量
- 优秀github项目的结构
	- 整体结构
	- 文档结构
	- 架构设计
	- 代码风格

# ToDO

- 技术文档化
- 代码优化
- 补全代码注释
- demo算法集成
- 控制器模块优化

- TFIDF模块中word level补全
- payload的解码

# Ref
- [如何从gensim word2vec获取词汇量？](https://codeday.me/bug/20190207/611442.html)
- [Docs » 数据预处理 » 文本预处理](https://keras.io/zh/preprocessing/text/)
- [Keras分词器 Tokenizer](http://codewithzhangyi.com/2019/04/23/keras-tokenizer/)